==> ag.db_2.0.2.tar.gz: ag.db/man/ag_dbconn.Rd <==
\name{ag_dbconn}

\alias{ag_dbconn}
\alias{ag_dbfile}
\alias{ag_dbschema}
\alias{ag_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  ag_dbconn()
  ag_dbfile()
  ag_dbschema(file="", show.indices=FALSE)
  ag_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{ag_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{ag_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{ag_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{ag_dbschema} prints the schema definition of the
  package annotation DB.

  \code{ag_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{ag_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{ag_dbfile}: a character string with the path to the
  package annotation DB.

  \code{ag_dbschema}: none (invisible \code{NULL}).

  \code{ag_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(ag_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by ag_dbconn() was created with:
  dbConnect(SQLite(), dbname=ag_dbfile(), cache_size=64000, synchronous=0)

  ag_dbschema()

  ag_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> ag.db_2.5.0.tar.gz: ag.db/man/ag_dbconn.Rd <==

\name{ag_dbconn}

\alias{ag_dbconn}
\alias{ag_dbfile}
\alias{ag_dbschema}
\alias{ag_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  ag_dbconn()
  ag_dbfile()
  ag_dbschema(file="", show.indices=FALSE)
  ag_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{ag_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{ag_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{ag_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{ag_dbschema} prints the schema definition of the
  package annotation DB.

  \code{ag_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{ag_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{ag_dbfile}: a character string with the path to the
  package annotation DB.

  \code{ag_dbschema}: none (invisible \code{NULL}).

  \code{ag_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(ag_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by ag_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=ag_dbfile(), cache_size=64000,
  synchronous=0)

  ag_dbschema()

  ag_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
